@@ -2,7 +2,7 @@
 
 from django.urls import path
 
-import core.views as views
+import roiburo.core.views as views
 
 urlpatterns = [
     path(
